import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_sandbox import NAME
from bluer_sandbox.assets.functions import publish
from bluer_sandbox.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="publish",
)
parser.add_argument(
    "--arg",
    type=bool,
    default=0,
    help="0|1",
)
parser.add_argument(
    "--object_name",
    type=str,
)
parser.add_argument(
    "--extensions",
    type=str,
    default="png",
    help="png+txt",
)
parser.add_argument(
    "--prefix",
    type=str,
    default="",
)
parser.add_argument(
    "--asset_name",
    type=str,
    default="",
)
args = parser.parse_args()

success = False
if args.task == "publish":
    success = publish(
        object_name=args.object_name,
        list_of_extensions=args.extensions.split("+"),
        prefix=args.prefix,
        asset_name=args.asset_name,
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_publish(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("download,", mono=mono),
            "extensions=png+txt",
            xtra(",~pull,", mono=mono),
            "push",
        ]
    )

    args = [
        "[--asset_name <other-object-name>]",
        "[--prefix <prefix>]",
    ]

    return show_usage(
        [
            "@assets",
            "publish",
            f"[{options}]",
            "[.|<object-name>]",
        ]
        + args,
        "<object-name>/<prefix> -> assets.",
        mono=mono,
    )


help_functions = {
    "publish": help_publish,
}



from blueness import module

from bluer_objects import file, objects
from bluer_objects.metadata import post_to_object

from bluer_sandbox import NAME
from bluer_sandbox.logger import logger


NAME = module.name(__file__, NAME)


def post_process(object_name: str) -> bool:
    logger.info(f"{NAME}.post_process({object_name})")

    success, prompt = file.load_text(
        objects.path_of(
            object_name=object_name,
            filename="prompt.txt",
        )
    )
    if not success:
        return success
    prompt = [line for line in prompt if line]

    success, output = file.load_text(
        objects.path_of(
            object_name=object_name,
            filename="output.txt",
        )
    )
    if not success:
        return success
    output = [line for line in output if line]

    return post_to_object(
        object_name,
        "post_process",
        {
            "prompt": prompt,
            "output": output,
        },
    )
